@@ -36,14 +36,17 @@ class Twitter_OAuthConsumer
 	public $key;
 	public $secret;
 
-	function __construct($key, $secret, $callback_url=NULL) {
+
+	public function __construct($key, $secret, $callback_url = null)
+	{
 		$this->key = $key;
 		$this->secret = $secret;
 		$this->callback_url = $callback_url;
 	}
 
 
-	function __toString() {
+	public function __toString()
+	{
 		return "OAuthConsumer[key=$this->key,secret=$this->secret]";
 	}
 }
@@ -54,11 +57,13 @@ class Twitter_OAuthToken
 	public $key;
 	public $secret;
 
+
 	/**
 	 * key = the token
 	 * secret = the token secret
 	 */
-	function __construct($key, $secret) {
+	public function __construct($key, $secret)
+	{
 		$this->key = $key;
 		$this->secret = $secret;
 	}
@@ -68,15 +73,17 @@ class Twitter_OAuthToken
 	 * generates the basic string serialization of a token that a server
 	 * would respond to request_token and access_token calls with
 	 */
-	function to_string() {
-		return "oauth_token=" .
+	public function to_string()
+	{
+		return 'oauth_token=' .
 					Twitter_OAuthUtil::urlencode_rfc3986($this->key) .
-					"&oauth_token_secret=" .
+					'&oauth_token_secret=' .
 					Twitter_OAuthUtil::urlencode_rfc3986($this->secret);
 	}
 
 
-	function __toString() {
+	public function __toString()
+	{
 		return $this->to_string();
 	}
 }
@@ -93,6 +100,7 @@ abstract class Twitter_OAuthSignatureMethod
 	 */
 	abstract public function get_name();
 
+
 	/**
 	 * Build up the signature
 	 * NOTE: The output of this function MUST NOT be urlencoded.
@@ -105,6 +113,7 @@ abstract class Twitter_OAuthSignatureMethod
 	 */
 	abstract public function build_signature($request, $consumer, $token);
 
+
 	/**
 	 * Verifies that a given signature is correct
 	 * @param Twitter_OAuthRequest $request
@@ -113,7 +122,8 @@ abstract class Twitter_OAuthSignatureMethod
 	 * @param string $signature
 	 * @return bool
 	 */
-	public function check_signature($request, $consumer, $token, $signature) {
+	public function check_signature($request, $consumer, $token, $signature)
+	{
 		$built = $this->build_signature($request, $consumer, $token);
 		return $built == $signature;
 	}
@@ -128,19 +138,21 @@ abstract class Twitter_OAuthSignatureMethod
  */
 class Twitter_OAuthSignatureMethod_HMAC_SHA1 extends Twitter_OAuthSignatureMethod
 {
-	function get_name() {
-		return "HMAC-SHA1";
+	public function get_name()
+	{
+		return 'HMAC-SHA1';
 	}
 
 
-	public function build_signature($request, $consumer, $token) {
+	public function build_signature($request, $consumer, $token)
+	{
 		$base_string = $request->get_signature_base_string();
 		$request->base_string = $base_string;
 
-		$key_parts = array(
+		$key_parts = [
 			$consumer->secret,
-			($token) ? $token->secret : ""
-		);
+			($token) ? $token->secret : '',
+		];
 
 		$key_parts = Twitter_OAuthUtil::urlencode_rfc3986($key_parts);
 		$key = implode('&', $key_parts);
@@ -156,8 +168,9 @@ class Twitter_OAuthSignatureMethod_HMAC_SHA1 extends Twitter_OAuthSignatureMetho
  */
 class Twitter_OAuthSignatureMethod_PLAINTEXT extends Twitter_OAuthSignatureMethod
 {
-	public function get_name() {
-		return "PLAINTEXT";
+	public function get_name()
+	{
+		return 'PLAINTEXT';
 	}
 
 
@@ -170,11 +183,12 @@ class Twitter_OAuthSignatureMethod_PLAINTEXT extends Twitter_OAuthSignatureMetho
 	 * Please note that the second encoding MUST NOT happen in the SignatureMethod, as
 	 * OAuthRequest handles this!
 	 */
-	public function build_signature($request, $consumer, $token) {
-		$key_parts = array(
+	public function build_signature($request, $consumer, $token)
+	{
+		$key_parts = [
 			$consumer->secret,
-			($token) ? $token->secret : ""
-		);
+			($token) ? $token->secret : '',
+		];
 
 		$key_parts = Twitter_OAuthUtil::urlencode_rfc3986($key_parts);
 		$key = implode('&', $key_parts);
@@ -194,25 +208,30 @@ class Twitter_OAuthSignatureMethod_PLAINTEXT extends Twitter_OAuthSignatureMetho
  */
 abstract class Twitter_OAuthSignatureMethod_RSA_SHA1 extends Twitter_OAuthSignatureMethod
 {
-	public function get_name() {
-		return "RSA-SHA1";
+	public function get_name()
+	{
+		return 'RSA-SHA1';
 	}
 
+
 	// Up to the SP to implement this lookup of keys. Possible ideas are:
 	// (1) do a lookup in a table of trusted certs keyed off of consumer
 	// (2) fetch via http using a url provided by the requester
 	// (3) some sort of specific discovery code based on request
 	//
 	// Either way should return a string representation of the certificate
-	protected abstract function fetch_public_cert(&$request);
+	abstract protected function fetch_public_cert(&$request);
+
 
 	// Up to the SP to implement this lookup of keys. Possible ideas are:
 	// (1) do a lookup in a table of trusted certs keyed off of consumer
 	//
 	// Either way should return a string representation of the certificate
-	protected abstract function fetch_private_cert(&$request);
+	abstract protected function fetch_private_cert(&$request);
 
-	public function build_signature($request, $consumer, $token) {
+
+	public function build_signature($request, $consumer, $token)
+	{
 		$base_string = $request->get_signature_base_string();
 		$request->base_string = $base_string;
 
@@ -232,8 +251,9 @@ abstract class Twitter_OAuthSignatureMethod_RSA_SHA1 extends Twitter_OAuthSignat
 	}
 
 
-	public function check_signature($request, $consumer, $token, $signature) {
-		$decoded_sig = base64_decode($signature);
+	public function check_signature($request, $consumer, $token, $signature)
+	{
+		$decoded_sig = base64_decode($signature, true);
 
 		$base_string = $request->get_signature_base_string();
 
@@ -255,17 +275,19 @@ abstract class Twitter_OAuthSignatureMethod_RSA_SHA1 extends Twitter_OAuthSignat
 
 class Twitter_OAuthRequest
 {
-	protected $parameters;
-	protected $http_method;
-	protected $http_url;
 	// for debug purposes
 	public $base_string;
 	public static $version = '1.0';
 	public static $POST_INPUT = 'php://input';
+	protected $parameters;
+	protected $http_method;
+	protected $http_url;
 
-	function __construct($http_method, $http_url, $parameters=NULL) {
-		$parameters = ($parameters) ? $parameters : array();
-		$parameters = array_merge( Twitter_OAuthUtil::parse_parameters(parse_url($http_url, PHP_URL_QUERY)), $parameters);
+
+	public function __construct($http_method, $http_url, $parameters = null)
+	{
+		$parameters = ($parameters) ? $parameters : [];
+		$parameters = array_merge(Twitter_OAuthUtil::parse_parameters(parse_url($http_url, PHP_URL_QUERY)), $parameters);
 		$this->parameters = $parameters;
 		$this->http_method = $http_method;
 		$this->http_url = $http_url;
@@ -275,8 +297,9 @@ class Twitter_OAuthRequest
 	/**
 	 * attempt to build up a request from what was passed to the server
 	 */
-	public static function from_request($http_method=NULL, $http_url=NULL, $parameters=NULL) {
-		$scheme = (!isset($_SERVER['HTTPS']) || $_SERVER['HTTPS'] != "on")
+	public static function from_request($http_method = null, $http_url = null, $parameters = null)
+	{
+		$scheme = (!isset($_SERVER['HTTPS']) || $_SERVER['HTTPS'] != 'on')
 							? 'http'
 							: 'https';
 		$http_url = ($http_url) ? $http_url : $scheme .
@@ -299,8 +322,8 @@ class Twitter_OAuthRequest
 
 			// It's a POST request of the proper content-type, so parse POST
 			// parameters and add those overriding any duplicates from GET
-			if ($http_method == "POST"
-					&&  isset($request_headers['Content-Type'])
+			if ($http_method == 'POST'
+					&& isset($request_headers['Content-Type'])
 					&& strstr($request_headers['Content-Type'],
 										'application/x-www-form-urlencoded')
 					) {
@@ -318,38 +341,40 @@ class Twitter_OAuthRequest
 				);
 				$parameters = array_merge($parameters, $header_parameters);
 			}
-
 		}
 
-		return new Twitter_OAuthRequest($http_method, $http_url, $parameters);
+		return new self($http_method, $http_url, $parameters);
 	}
 
 
 	/**
 	 * pretty much a helper function to set up the request
 	 */
-	public static function from_consumer_and_token($consumer, $token, $http_method, $http_url, $parameters=NULL) {
-		$parameters = ($parameters) ?  $parameters : array();
-		$defaults = array("oauth_version" => Twitter_OAuthRequest::$version,
-											"oauth_nonce" => Twitter_OAuthRequest::generate_nonce(),
-											"oauth_timestamp" => Twitter_OAuthRequest::generate_timestamp(),
-											"oauth_consumer_key" => $consumer->key);
-		if ($token)
+	public static function from_consumer_and_token($consumer, $token, $http_method, $http_url, $parameters = null)
+	{
+		$parameters = ($parameters) ? $parameters : [];
+		$defaults = ['oauth_version' => self::$version,
+											'oauth_nonce' => self::generate_nonce(),
+											'oauth_timestamp' => self::generate_timestamp(),
+											'oauth_consumer_key' => $consumer->key, ];
+		if ($token) {
 			$defaults['oauth_token'] = $token->key;
+		}
 
 		$parameters = array_merge($defaults, $parameters);
 
-		return new Twitter_OAuthRequest($http_method, $http_url, $parameters);
+		return new self($http_method, $http_url, $parameters);
 	}
 
 
-	public function set_parameter($name, $value, $allow_duplicates = true) {
+	public function set_parameter($name, $value, $allow_duplicates = true)
+	{
 		if ($allow_duplicates && isset($this->parameters[$name])) {
 			// We have already added parameter(s) with this name, so add to the list
 			if (is_scalar($this->parameters[$name])) {
 				// This is the first duplicate, so transform scalar (string)
 				// into an array so we can add the duplicates
-				$this->parameters[$name] = array($this->parameters[$name]);
+				$this->parameters[$name] = [$this->parameters[$name]];
 			}
 
 			$this->parameters[$name][] = $value;
@@ -359,17 +384,20 @@ class Twitter_OAuthRequest
 	}
 
 
-	public function get_parameter($name) {
+	public function get_parameter($name)
+	{
 		return isset($this->parameters[$name]) ? $this->parameters[$name] : null;
 	}
 
 
-	public function get_parameters() {
+	public function get_parameters()
+	{
 		return $this->parameters;
 	}
 
 
-	public function unset_parameter($name) {
+	public function unset_parameter($name)
+	{
 		unset($this->parameters[$name]);
 	}
 
@@ -378,7 +406,8 @@ class Twitter_OAuthRequest
 	 * The request parameters, sorted and concatenated into a normalized string.
 	 * @return string
 	 */
-	public function get_signable_parameters() {
+	public function get_signable_parameters()
+	{
 		// Grab all parameters
 		$params = $this->parameters;
 
@@ -399,12 +428,13 @@ class Twitter_OAuthRequest
 	 * and the parameters (normalized), each urlencoded
 	 * and the concated with &.
 	 */
-	public function get_signature_base_string() {
-		$parts = array(
+	public function get_signature_base_string()
+	{
+		$parts = [
 			$this->get_normalized_http_method(),
 			$this->get_normalized_http_url(),
-			$this->get_signable_parameters()
-		);
+			$this->get_signable_parameters(),
+		];
 
 		$parts = Twitter_OAuthUtil::urlencode_rfc3986($parts);
 
@@ -415,7 +445,8 @@ class Twitter_OAuthRequest
 	/**
 	 * just uppercases the http method
 	 */
-	public function get_normalized_http_method() {
+	public function get_normalized_http_method()
+	{
 		return strtoupper($this->http_method);
 	}
 
@@ -424,7 +455,8 @@ class Twitter_OAuthRequest
 	 * parses the url and rebuilds it to be
 	 * scheme://host/path
 	 */
-	public function get_normalized_http_url() {
+	public function get_normalized_http_url()
+	{
 		$parts = parse_url($this->http_url);
 
 		$scheme = (isset($parts['scheme'])) ? $parts['scheme'] : 'http';
@@ -443,11 +475,12 @@ class Twitter_OAuthRequest
 	/**
 	 * builds a url usable for a GET request
 	 */
-	public function to_url() {
+	public function to_url()
+	{
 		$post_data = $this->to_postdata();
 		$out = $this->get_normalized_http_url();
 		if ($post_data) {
-			$out .= '?'.$post_data;
+			$out .= '?' . $post_data;
 		}
 		return $out;
 	}
@@ -456,7 +489,8 @@ class Twitter_OAuthRequest
 	/**
 	 * builds the data one would send in a POST request
 	 */
-	public function to_postdata() {
+	public function to_postdata()
+	{
 		return Twitter_OAuthUtil::build_http_query($this->parameters);
 	}
 
@@ -464,17 +498,21 @@ class Twitter_OAuthRequest
 	/**
 	 * builds the Authorization: header
 	 */
-	public function to_header($realm=null) {
+	public function to_header($realm = null)
+	{
 		$first = true;
-	if($realm) {
+		if ($realm) {
 			$out = 'Authorization: OAuth realm="' . Twitter_OAuthUtil::urlencode_rfc3986($realm) . '"';
 			$first = false;
-		} else
+		} else {
 			$out = 'Authorization: OAuth';
+		}
 
-		$total = array();
+		$total = [];
 		foreach ($this->parameters as $k => $v) {
-			if (substr($k, 0, 5) != "oauth") continue;
+			if (substr($k, 0, 5) != 'oauth') {
+				continue;
+			}
 			if (is_array($v)) {
 				throw new Twitter_OAuthException('Arrays not supported in headers');
 			}
@@ -489,23 +527,26 @@ class Twitter_OAuthRequest
 	}
 
 
-	public function __toString() {
+	public function __toString()
+	{
 		return $this->to_url();
 	}
 
 
-	public function sign_request($signature_method, $consumer, $token) {
+	public function sign_request($signature_method, $consumer, $token)
+	{
 		$this->set_parameter(
-			"oauth_signature_method",
+			'oauth_signature_method',
 			$signature_method->get_name(),
 			false
 		);
 		$signature = $this->build_signature($signature_method, $consumer, $token);
-		$this->set_parameter("oauth_signature", $signature, false);
+		$this->set_parameter('oauth_signature', $signature, false);
 	}
 
 
-	public function build_signature($signature_method, $consumer, $token) {
+	public function build_signature($signature_method, $consumer, $token)
+	{
 		$signature = $signature_method->build_signature($this, $consumer, $token);
 		return $signature;
 	}
@@ -514,7 +555,8 @@ class Twitter_OAuthRequest
 	/**
 	 * util function: current timestamp
 	 */
-	private static function generate_timestamp() {
+	private static function generate_timestamp()
+	{
 		return time();
 	}
 
@@ -522,7 +564,8 @@ class Twitter_OAuthRequest
 	/**
 	 * util function: current nonce
 	 */
-	private static function generate_nonce() {
+	private static function generate_nonce()
+	{
 		$mt = microtime();
 		$rand = mt_rand();
 
@@ -534,33 +577,39 @@ class Twitter_OAuthServer
 {
 	protected $timestamp_threshold = 300; // in seconds, five minutes
 	protected $version = '1.0';             // hi blaine
-	protected $signature_methods = array();
+	protected $signature_methods = [];
 
 	protected $data_store;
 
-	function __construct($data_store) {
+
+	public function __construct($data_store)
+	{
 		$this->data_store = $data_store;
 	}
 
 
-	public function add_signature_method($signature_method) {
+	public function add_signature_method($signature_method)
+	{
 		$this->signature_methods[$signature_method->get_name()] =
 			$signature_method;
 	}
 
+
 	// high level functions
 
+
 	/**
 	 * process a request_token request
 	 * returns the request token on success
 	 */
-	public function fetch_request_token(&$request) {
+	public function fetch_request_token(&$request)
+	{
 		$this->get_version($request);
 
 		$consumer = $this->get_consumer($request);
 
 		// no token required for the initial token request
-		$token = NULL;
+		$token = null;
 
 		$this->check_signature($request, $consumer, $token);
 
@@ -576,13 +625,14 @@ class Twitter_OAuthServer
 	 * process an access_token request
 	 * returns the access token on success
 	 */
-	public function fetch_access_token(&$request) {
+	public function fetch_access_token(&$request)
+	{
 		$this->get_version($request);
 
 		$consumer = $this->get_consumer($request);
 
 		// requires authorized request token
-		$token = $this->get_token($request, $consumer, "request");
+		$token = $this->get_token($request, $consumer, 'request');
 
 		$this->check_signature($request, $consumer, $token);
 
@@ -597,20 +647,25 @@ class Twitter_OAuthServer
 	/**
 	 * verify an api call, checks all the parameters
 	 */
-	public function verify_request(&$request) {
+	public function verify_request(&$request)
+	{
 		$this->get_version($request);
 		$consumer = $this->get_consumer($request);
-		$token = $this->get_token($request, $consumer, "access");
+		$token = $this->get_token($request, $consumer, 'access');
 		$this->check_signature($request, $consumer, $token);
-		return array($consumer, $token);
+		return [$consumer, $token];
 	}
 
+
 	// Internals from here
+
+
 	/**
 	 * version 1
 	 */
-	private function get_version(&$request) {
-		$version = $request->get_parameter("oauth_version");
+	private function get_version(&$request)
+	{
+		$version = $request->get_parameter('oauth_version');
 		if (!$version) {
 			// Service Providers MUST assume the protocol version to be 1.0 if this parameter is not present.
 			// Chapter 7.0 ("Accessing Protected Ressources")
@@ -626,10 +681,11 @@ class Twitter_OAuthServer
 	/**
 	 * figure out the signature with some defaults
 	 */
-	private function get_signature_method($request) {
+	private function get_signature_method($request)
+	{
 		$signature_method = $request instanceof Twitter_OAuthRequest
-				? $request->get_parameter("oauth_signature_method")
-				: NULL;
+				? $request->get_parameter('oauth_signature_method')
+				: null;
 
 		if (!$signature_method) {
 			// According to chapter 7 ("Accessing Protected Ressources") the signature-method
@@ -638,11 +694,11 @@ class Twitter_OAuthServer
 		}
 
 		if (!in_array($signature_method,
-									array_keys($this->signature_methods))) {
+									array_keys($this->signature_methods), true)) {
 			throw new Twitter_OAuthException(
 				"Signature method '$signature_method' not supported " .
-				"try one of the following: " .
-				implode(", ", array_keys($this->signature_methods))
+				'try one of the following: ' .
+				implode(', ', array_keys($this->signature_methods))
 			);
 		}
 		return $this->signature_methods[$signature_method];
@@ -652,18 +708,19 @@ class Twitter_OAuthServer
 	/**
 	 * try to find the consumer for the provided request's consumer key
 	 */
-	private function get_consumer($request) {
+	private function get_consumer($request)
+	{
 		$consumer_key = $request instanceof Twitter_OAuthRequest
-				? $request->get_parameter("oauth_consumer_key")
-				: NULL;
+				? $request->get_parameter('oauth_consumer_key')
+				: null;
 
 		if (!$consumer_key) {
-			throw new Twitter_OAuthException("Invalid consumer key");
+			throw new Twitter_OAuthException('Invalid consumer key');
 		}
 
 		$consumer = $this->data_store->lookup_consumer($consumer_key);
 		if (!$consumer) {
-			throw new Twitter_OAuthException("Invalid consumer");
+			throw new Twitter_OAuthException('Invalid consumer');
 		}
 
 		return $consumer;
@@ -673,10 +730,11 @@ class Twitter_OAuthServer
 	/**
 	 * try to find the token for the provided request's token key
 	 */
-	private function get_token($request, $consumer, $token_type="access") {
+	private function get_token($request, $consumer, $token_type = 'access')
+	{
 		$token_field = $request instanceof Twitter_OAuthRequest
 				? $request->get_parameter('oauth_token')
-				: NULL;
+				: null;
 
 		$token = $this->data_store->lookup_token(
 			$consumer, $token_type, $token_field
@@ -692,14 +750,15 @@ class Twitter_OAuthServer
 	 * all-in-one function to check the signature on a request
 	 * should guess the signature method appropriately
 	 */
-	private function check_signature($request, $consumer, $token) {
+	private function check_signature($request, $consumer, $token)
+	{
 		// this should probably be in a different method
 		$timestamp = $request instanceof Twitter_OAuthRequest
 				? $request->get_parameter('oauth_timestamp')
-				: NULL;
+				: null;
 		$nonce = $request instanceof Twitter_OAuthRequest
 				? $request->get_parameter('oauth_nonce')
-				: NULL;
+				: null;
 
 		$this->check_timestamp($timestamp);
 		$this->check_nonce($consumer, $token, $nonce, $timestamp);
@@ -715,7 +774,7 @@ class Twitter_OAuthServer
 		);
 
 		if (!$valid_sig) {
-			throw new Twitter_OAuthException("Invalid signature");
+			throw new Twitter_OAuthException('Invalid signature');
 		}
 	}
 
@@ -723,11 +782,13 @@ class Twitter_OAuthServer
 	/**
 	 * check that the timestamp is new enough
 	 */
-	private function check_timestamp($timestamp) {
-		if( ! $timestamp )
+	private function check_timestamp($timestamp)
+	{
+		if (!$timestamp) {
 			throw new Twitter_OAuthException(
 				'Missing timestamp parameter. The parameter is required'
 			);
+		}
 
 		// verify that timestamp is recentish
 		$now = time();
@@ -742,11 +803,13 @@ class Twitter_OAuthServer
 	/**
 	 * check that the nonce is not repeated
 	 */
-	private function check_nonce($consumer, $token, $nonce, $timestamp) {
-		if( ! $nonce )
+	private function check_nonce($consumer, $token, $nonce, $timestamp)
+	{
+		if (!$nonce) {
 			throw new Twitter_OAuthException(
 				'Missing nonce parameter. The parameter is required'
 			);
+		}
 
 		// verify that the nonce is uniqueish
 		$found = $this->data_store->lookup_nonce(
@@ -759,53 +822,59 @@ class Twitter_OAuthServer
 			throw new Twitter_OAuthException("Nonce already used: $nonce");
 		}
 	}
-
 }
 
 class Twitter_OAuthDataStore
 {
-	function lookup_consumer($consumer_key) {
+	public function lookup_consumer($consumer_key)
+	{
 		// implement me
 	}
 
 
-	function lookup_token($consumer, $token_type, $token) {
+	public function lookup_token($consumer, $token_type, $token)
+	{
 		// implement me
 	}
 
 
-	function lookup_nonce($consumer, $token, $nonce, $timestamp) {
+	public function lookup_nonce($consumer, $token, $nonce, $timestamp)
+	{
 		// implement me
 	}
 
 
-	function new_request_token($consumer, $callback = null) {
+	public function new_request_token($consumer, $callback = null)
+	{
 		// return a new token attached to this consumer
 	}
 
 
-	function new_access_token($token, $consumer, $verifier = null) {
+	public function new_access_token($token, $consumer, $verifier = null)
+	{
 		// return a new access token attached to this consumer
 		// for the user associated with this token if the request token
 		// is authorized
 		// should also invalidate the request token
 	}
-
 }
 
 class Twitter_OAuthUtil
 {
-	public static function urlencode_rfc3986($input) {
+	public static function urlencode_rfc3986($input)
+	{
 		if (is_array($input)) {
-			return array_map(array('Twitter_OAuthUtil', 'urlencode_rfc3986'), $input);
-		} else if (is_scalar($input)) {
-			return str_replace(
+			return array_map(['Twitter_OAuthUtil', 'urlencode_rfc3986'], $input);
+		} else {
+			if (is_scalar($input)) {
+				return str_replace(
 				'+',
 				' ',
 				str_replace('%7E', '~', rawurlencode($input))
 			);
-		} else {
-			return '';
+			} else {
+				return '';
+			}
 		}
 	}
 
@@ -813,20 +882,23 @@ class Twitter_OAuthUtil
 	// This decode function isn't taking into consideration the above
 	// modifications to the encoding process. However, this method doesn't
 	// seem to be used anywhere so leaving it as is.
-	public static function urldecode_rfc3986($string) {
+	public static function urldecode_rfc3986($string)
+	{
 		return urldecode($string);
 	}
 
+
 	// Utility function for turning the Authorization: header into
 	// parameters, has to do some unescaping
 	// Can filter out any non-oauth parameters if needed (default behaviour)
 	// May 28th, 2010 - method updated to tjerk.meesters for a speed improvement.
 	//                  see http://code.google.com/p/oauth/issues/detail?id=163
-	public static function split_header($header, $only_allow_oauth_parameters = true) {
-		$params = array();
-		if (preg_match_all('/('.($only_allow_oauth_parameters ? 'oauth_' : '').'[a-z_-]*)=(:?"([^"]*)"|([^,]*))/', $header, $matches)) {
+	public static function split_header($header, $only_allow_oauth_parameters = true)
+	{
+		$params = [];
+		if (preg_match_all('/(' . ($only_allow_oauth_parameters ? 'oauth_' : '') . '[a-z_-]*)=(:?"([^"]*)"|([^,]*))/', $header, $matches)) {
 			foreach ($matches[1] as $i => $h) {
-				$params[$h] = Twitter_OAuthUtil::urldecode_rfc3986(empty($matches[3][$i]) ? $matches[4][$i] : $matches[3][$i]);
+				$params[$h] = self::urldecode_rfc3986(empty($matches[3][$i]) ? $matches[4][$i] : $matches[3][$i]);
 			}
 			if (isset($params['realm'])) {
 				unset($params['realm']);
@@ -835,8 +907,10 @@ class Twitter_OAuthUtil
 		return $params;
 	}
 
+
 	// helper to try to sort out headers for people who aren't running apache
-	public static function get_headers() {
+	public static function get_headers()
+	{
 		if (function_exists('apache_request_headers')) {
 			// we need this to get the actual Authorization: header
 			// because apache tends to tell us it doesn't exist
@@ -846,33 +920,35 @@ class Twitter_OAuthUtil
 			// we always want the keys to be Cased-Like-This and arh()
 			// returns the headers in the same case as they are in the
 			// request
-			$out = array();
-			foreach ($headers AS $key => $value) {
+			$out = [];
+			foreach ($headers as $key => $value) {
 				$key = str_replace(
-						" ",
-						"-",
-						ucwords(strtolower(str_replace("-", " ", $key)))
+						' ',
+						'-',
+						ucwords(strtolower(str_replace('-', ' ', $key)))
 					);
 				$out[$key] = $value;
 			}
 		} else {
 			// otherwise we don't have apache and are just going to have to hope
 			// that $_SERVER actually contains what we need
-			$out = array();
-			if( isset($_SERVER['CONTENT_TYPE']) )
+			$out = [];
+			if (isset($_SERVER['CONTENT_TYPE'])) {
 				$out['Content-Type'] = $_SERVER['CONTENT_TYPE'];
-			if( isset($_ENV['CONTENT_TYPE']) )
+			}
+			if (isset($_ENV['CONTENT_TYPE'])) {
 				$out['Content-Type'] = $_ENV['CONTENT_TYPE'];
+			}
 
 			foreach ($_SERVER as $key => $value) {
-				if (substr($key, 0, 5) == "HTTP_") {
+				if (substr($key, 0, 5) == 'HTTP_') {
 					// this is chaos, basically it is just there to capitalize the first
 					// letter of every word that is not an initial HTTP and strip HTTP
 					// code from przemek
 					$key = str_replace(
-						" ",
-						"-",
-						ucwords(strtolower(str_replace("_", " ", substr($key, 5))))
+						' ',
+						'-',
+						ucwords(strtolower(str_replace('_', ' ', substr($key, 5))))
 					);
 					$out[$key] = $value;
 				}
@@ -881,19 +957,23 @@ class Twitter_OAuthUtil
 		return $out;
 	}
 
+
 	// This function takes a input like a=b&a=c&d=e and returns the parsed
 	// parameters like this
-	// array('a' => array('b','c'), 'd' => 'e')
-	public static function parse_parameters( $input ) {
-		if (!isset($input) || !$input) return array();
+	// ['a' => array('b','c'), 'd' => 'e']
+	public static function parse_parameters($input)
+	{
+		if (!isset($input) || !$input) {
+			return [];
+		}
 
 		$pairs = explode('&', $input);
 
-		$parsed_parameters = array();
+		$parsed_parameters = [];
 		foreach ($pairs as $pair) {
 			$split = explode('=', $pair, 2);
-			$parameter = Twitter_OAuthUtil::urldecode_rfc3986($split[0]);
-			$value = isset($split[1]) ? Twitter_OAuthUtil::urldecode_rfc3986($split[1]) : '';
+			$parameter = self::urldecode_rfc3986($split[0]);
+			$value = isset($split[1]) ? self::urldecode_rfc3986($split[1]) : '';
 
 			if (isset($parsed_parameters[$parameter])) {
 				// We have already recieved parameter(s) with this name, so add to the list
@@ -902,7 +982,7 @@ class Twitter_OAuthUtil
 				if (is_scalar($parsed_parameters[$parameter])) {
 					// This is the first duplicate, so transform scalar (string) into an array
 					// so we can add the duplicates
-					$parsed_parameters[$parameter] = array($parsed_parameters[$parameter]);
+					$parsed_parameters[$parameter] = [$parsed_parameters[$parameter]];
 				}
 
 				$parsed_parameters[$parameter][] = $value;
@@ -914,19 +994,22 @@ class Twitter_OAuthUtil
 	}
 
 
-	public static function build_http_query($params) {
-		if (!$params) return '';
+	public static function build_http_query($params)
+	{
+		if (!$params) {
+			return '';
+		}
 
 		// Urlencode both keys and values
-		$keys = Twitter_OAuthUtil::urlencode_rfc3986(array_keys($params));
-		$values = Twitter_OAuthUtil::urlencode_rfc3986(array_values($params));
+		$keys = self::urlencode_rfc3986(array_keys($params));
+		$values = self::urlencode_rfc3986(array_values($params));
 		$params = array_combine($keys, $values);
 
 		// Parameters are sorted by name, using lexicographical byte value ordering.
 		// Ref: Spec: 9.1.1 (1)
 		uksort($params, 'strcmp');
 
-		$pairs = array();
+		$pairs = [];
 		foreach ($params as $parameter => $value) {
 			if (is_array($value)) {
 				// If two or more parameters share the same name, they are sorted by their value
